% options     
    % ECOC: CODING DESIGN
    % choose the coding design. available designs: 'onevsone', 'onevsall',
    % 'ordinal'
    coding = 'ordinal';
    
    % ECOC: ORDINAL ORDER
    % for the ordinal coding design to work, you have to specify the
    % ordinal order of the categories. Gain this information from Step 3.
    % only effective if coding = 'ordinal'
    ordinalOrder = {'sparkling water';'cola';'apple juice';'wine'};
    
    % EXERCISE
    % in the exercises, we use the features 284 and 371.
    % To improve accuracy in the exercises, we collected
    % extra data only on those temperatures (313°C
    % and 400 °C). If exercise == true, the extra data
    % will be loaded. Set this to false if you have your
    % own dataset or try different features!
    exercise = true;
  
    % STANDARDIZATION
    % standardize data before training? usually leads to better results
    standardize = true;    
        
%------------------------
addpath('lib');

load("allTemperatures30-400.mat")
load("selectedFeatures.mat")


if exercise
if exist('additionalTrainingData313and400.mat', 'file') == 2
% import additional training data

load("additionalTrainingData313and400.mat")
X = [X;XAdditional];
Ycategories = [Ycategories;YcategoriesAdditional];
end
end


% standardize data
 if standardize
     Xarray = table2array(X);
     Xmean = mean(Xarray);
     Xstd = std(Xarray);
     Xarray = (Xarray - Xmean) ./ Xstd;
     X = array2table(Xarray);
 end

 
% execute the training
Mdl = executeECOC_SVMTraining(X(:,selectedFeatures), Ycategories,...
     coding, ordinalOrder);
 


% save ECOC Model
if standardize
   save('ecocmodel.mat','Mdl','coding','Xmean','Xstd');
else
    save('ecocmodel.mat','Mdl','coding');
end
    
%plotting
if (strcmp(coding,'ordinal'))
    w = []; w0 = [];
    % plot standardized data with hyperplanes if coding design == ordinal
    for i = 1:numel(Mdl.BinaryLearners)
        w = [w, Mdl.BinaryLearners{i}.Beta];
        w0 = [w0, Mdl.BinaryLearners{i}.Bias];   
    end
    createPlotsUpTo3D(X,Ycategories,selectedFeatures, ordinalOrder, w, w0);
else
    % plot standardized data without hyperplanes
    createPlotsUpTo3D(X,Ycategories,selectedFeatures);
end
